@@ -29,6 +29,10 @@ export montage
 const montage_path = "/usr/bin/montage"
 montage(f::Function; kw...) = f(montage_path)
 montage(; kw...) = Cmd([montage_path])
+export magick
+const magick_path = "/usr/bin/magick"
+magick(f::Function; kw...) = f(magick_path)
+magick(; kw...) = Cmd([magick_path])
 function __init__()
     global libwand_handle = dlopen(libwand_path)
 end
